<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/bootstrap.min.css') }}">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/index.css') }}">
    <link rel="shortcut icon" href="{{ url_for('static', filename='images/favicon.ico') }}">
    <title>Authentication</title>
</head>

<body>
    <div class="container">
        <div class="d-flex justify-content-center mt-5">
            <div class="text-center">
                <img class="img-responsive" src="{{ url_for('static', filename='images/graphenex_logo_white.png') }}"
                    alt="logo" height="200" width="200" id="banner">
                <h3>grapheneX</h3><hr class="fancy-hr"> 
                <form method="POST" autocomplete="off" id="authform">
                    <div class="form-group">
                        <input class="form-control" type="password" name="token" id="token" placeholder="Access token">
                        {% with messages = get_flashed_messages() %}
                            {% if messages %}
                                {% for message in messages %}
                                    <small class="form-text text-muted">{{ message }}</small>
                                {% endfor %}
                            {% endif %}
                        {% endwith %}
                        <button class="btn btn-block mt-2" type="submit">Verify</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <script src="{{ url_for('static', filename='js/bootstrap.min.js') }}"></script>
</body>

</html>