/*
    grapheneX web main CSS file
*/

html,
body {
    margin: 0;
    background-color: #1E1E1E;
    color: white;
    height: 100%;
}


a {
    color: #1DA1F2;
}

.btn {
    border: 1px solid #1DA1F2;
    color: white;
}

.btn-danger {
    border: 1px solid #D8D8D8;
}

.btn-primary {
    background-color: #303030;
    border: 1px solid #D8D8D8;
}

.btn:hover {
    color: white;
    border: 1px solid #D8D8D8;
    opacity: 0.8;
}

.btn-primary:hover {
    background-color: #303030;
    opacity: 0.7;
}

.form-control {
    background-color: #111111;
    color: #D8D8D8;
}

.form-control:focus {
    color: #D8D8D8;
    opacity: 0.7;
    border-color: #D8D8D8;
    background-color: #111111;
    box-shadow: inset 0 .5px .5px rgba(0, 0, 0, 0.075), 0 0 3px rgba(255, 255, 255, 0.6);
}

.input-group-text {
    background-color: #111111;
    color: #D8D8D8;
}

.consolas {
    font-family: monospace;
}

.font-small {
    font-size: 12px;
}

.deep {
    -webkit-box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.5);
    -moz-box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.5);
    box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.5);
}

.box {
    padding: 30px;
    padding-bottom: 10px;
    border: 2px solid #1DA1F2;
    border-radius: 32px;
}

.systemstat {
    padding: 20px;
    border: 2px solid #1DA1F2;
    border-radius: 32px;
}

hr {
    margin-top: 0px;
    margin-bottom: 1rem;
    background-image: linear-gradient(90deg, white, transparent);
    border: 0;
    height: 1px;
}

.module-box {
    padding: 10px;
    border: 1px solid #1DA1F2;
    border-radius: 16px;
}

.table-dark {
    background-color: #111111;
}

.progress-bar {
    background-color: #1DA1F2;
}

.sr-bar {
    padding: 10px;
    font-size: 12px;
    border: 1px solid #1DA1F2;
    border-right: none;
    float: left;
    width: 90%;
    background: #1E1E1E;
    color: #D8D8D8;
    -webkit-border-top-left-radius: 5px;
    -webkit-border-bottom-left-radius: 5px;
    -moz-border-radius-topleft: 5px;
    -moz-border-radius-bottomleft: 5px;
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px;
}

.sr-bar:hover {
    border-right: none !important;
}

.sr-bar:focus {
    outline-width: 0;
}

.sr-btn {
    float: left;
    width: 10%;
    padding: 10px;
    background: #1E1E1E;
    color: white;
    font-size: 12px;
    border: 1px solid #1DA1F2;
    border-left: none;
    -webkit-border-top-right-radius: 5px;
    -webkit-border-bottom-right-radius: 5px;
    -moz-border-radius-topright: 5px;
    -moz-border-radius-bottomright: 5px;
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px;
}

.drawer-content {
    width: 100%;
    display: none;
}

.logs {
    background-color: #111111;
    width: 100%;
    border-radius: 5px;
    padding: 5px;
    padding-left: 10px;
}

.fa-arrow-circle-right {
    transition: all .4s ease;
}

.list-group {
    border: 1px solid #D8D8D8;
    border-radius: .25rem;
    max-height: 100px;
    margin-bottom: 10px;
    overflow-y:scroll;
    -webkit-overflow-scrolling: touch;
}

.list-group-item {
    background-color: #111111;
    color: #D8D8D8;
}

.fancy-hr {
    border: 0;
    background-image:  radial-gradient(
        #D8D8D8,
        #1e1e1e
      );
    height: 1px;
}

.list-group-item.active {
    background-color: #555;
    border-color: #1E1E1E;
}

::-webkit-scrollbar-track {
    -webkit-box-shadow: inset 0 0 6px rgba(0, 0, 0, 0.3);
    border-radius: 3px;
    background-color: #343A40;
}

::-webkit-scrollbar {
    width: 5px;
    background-color: #343A40;
}

::-webkit-scrollbar-thumb {
    border-radius: 3px;
    -webkit-box-shadow: inset 0 0 6px rgba(0, 0, 0, .3);
    background-color: #555;
}

.addmd-modal {
    background-color: #1E1E1E;
}

.rotated {
    -webkit-transform: rotate(45deg);
    /* Chrome, Safari 3.1+ */
    -moz-transform: rotate(45deg);
    /* Firefox 3.5-15 */
    -ms-transform: rotate(45deg);
    /* IE 9 */
    -o-transform: rotate(45deg);
    /* Opera 10.50-12.00 */
    transform: rotate(90deg);
    /* Firefox 16+, IE 10+, Opera 12.10+ */
}

@keyframes rotate_ar {
    100% {
        -webkit-transform: rotate(360deg);
    }
}

.rotate_cogs {
    animation: rotate_ar 2s linear infinite;
}

.rotate_arrow {
    -webkit-transform: rotate(180deg);
    /* Chrome, Safari 3.1+ */
    -moz-transform: rotate(180deg);
    /* Firefox 3.5-15 */
    -ms-transform: rotate(180deg);
    /* IE 9 */
    -o-transform: rotate(180deg);
    /* Opera 10.50-12.00 */
    transform: rotate(180deg);
    /* Firefox 16+, IE 10+, Opera 12.10+ */
}

.fa-chevron-down {
    transition: all .4s ease;
}
.opensystembtn:hover {
    outline: none;
    box-shadow: none !important;
    -webkit-appearance: none;
}



.overlay {
    position: fixed;
    top: 0;
    width: 100%;
    height: 100%;
    background-color: #1E1E1E;
    z-index: 100;
}

.loading-img {
    margin-top: 200px;
    animation: spin 2s linear infinite;
}


@keyframes spin {
    0% {
        -webkit-transform: rotateY(0);
    }
    50% {
        -webkit-transform: rotateY(0.5turn);
    }
    100%{
        -webkit-transform: rotateY(1turn);
    }
}

@media (min-width: 768px) {
    #systemdiv {
        display: block;
    }
}